==> snipe-it-6.3.0.zip: snipe-it-6.3.0/resources/lang/hu-HU/mail.php <==
<?php

return [
    'acceptance_asset_accepted' => 'A felhasználó elfogadott egy tételt',
    'acceptance_asset_declined' => 'A felhasználó visszautasított egy tételt',
    'a_user_canceled' => 'A felhasználó törölte az elemkérést a webhelyen',
    'a_user_requested' => 'A felhasználó egy elemet kért a webhelyen',
    'accessory_name' => 'Tartozéknév:',
    'additional_notes' => 'További megjegyzések:',
    'admin_has_created' => 'A rendszergazda létrehozott egy fiókot az alábbi weboldalon:',
    'asset' => 'Eszköz:',
    'asset_name' => 'Eszköz neve:',
    'asset_requested' => 'Asset requested',
    'asset_tag' => 'Eszköz azonosító',
    'assigned_to' => 'Hozzárendelve',
    'best_regards' => 'Üdvözlettel,',
    'canceled' => 'Megszakítva:',
    'checkin_date' => 'Visszavétel dátuma:',
    'checkout_date' => 'Kiadási dátum:',
    'click_to_confirm' => 'Kérjük, kattintson az alábbi linkre a weboldal megerősítéséhez: web account:',
    'click_on_the_link_accessory' => 'Az alján lévő linkre kattintva ellenőrizheti, hogy megkapta-e a tartozékot.',
    'click_on_the_link_asset' => 'Kérjük, kattintson az alul lévő linkre annak megerősítéséhez, hogy megkapták az eszközt.',
    'Confirm_Asset_Checkin' => 'Eszköz visszavételének megerősítése',
    'Confirm_Accessory_Checkin' => 'Tartozék visszavételének megerősítése',
    'Confirm_accessory_delivery' => 'Tartozék átvételének megerősítése',
    'Confirm_license_delivery' => 'Licensz átvételének megerősítése',
    'Confirm_asset_delivery' => 'Eszköz átvételének megerősítése',
    'Confirm_consumable_delivery' => 'Fogyóeszköz átvételének megerősítése',
    'current_QTY' => 'Jelenlegi QTY',
    'Days' => 'Nap',
    'days' => 'Nap',
    'expecting_checkin_date' => 'Várható visszaadás dátuma:',
    'expires' => 'Lejárat',
    'Expiring_Assets_Report' => 'Eszközök lejárati jelentése.',
    'Expiring_Licenses_Report' => 'Az engedélyekről szóló jelentés lejárata.',
    'hello' => 'Helló',
    'hi' => 'Üdv',
    'i_have_read' => 'Elolvastam és elfogadom a felhasználási feltételeket, és megkaptuk ezt az elemet.',
    'item' => 'Tétel:',
    'Item_Request_Canceled' => 'Elemkérelem törölve',
    'Item_Requested' => 'Kért elem',
    'link_to_update_password' => 'Kérjük, kattintson a következő linkre a frissítéshez: webes jelszó:',
    'login_first_admin' => 'Jelentkezzen be az új Snipe-IT telepítésébe az alábbi hitelesítő adatok alapján:',
    'login' => 'Belépés:',
    'Low_Inventory_Report' => 'Alacsony készletjelentés',
    'inventory_report' => 'Készlet Jelentés',
    'min_QTY' => 'Min QTY',
    'name' => 'Név',
    'new_item_checked' => 'Egy új elemet az Ön neve alatt ellenőriztek, a részletek lent találhatók.',
    'password' => 'Jelszó:',
    'password_reset' => 'Jelszó visszaállítása',

    'read_the_terms' => 'Kérjük, olvassa el az alábbi használati feltételeket.',
    'read_the_terms_and_click' => 'Kérjük, olvassa el az alábbi használati feltételeket, és kattintson az alul lévő linkre annak megerősítéséhez, hogy olvassa el és elfogadja a használati feltételeket, és megkapta az eszközt.',
    'requested' => 'Kérve:',
    'reset_link' => 'Jelszó visszaállítása linkre',
    'reset_password' => 'Kattintson ide a jelszó visszaállításához:',
    'serial' => 'Sorozatszám',
    'supplier' => 'Támogató',
    'tag' => 'Címke',
    'test_email' => 'Tesztelje az e-mailt a Snipe-IT-től',
    'test_mail_text' => 'Ez a Snipe-IT Asset Management System tesztje. Ha ez megvan, a levél működik :)',
    'the_following_item' => 'A következő tételt ellenőrzik:',
    'low_inventory_alert' => ':count darab tétel érhető el, ami kevesebb mint a minimum készlet vagy hamarosan kevesebb lesz.',
    'assets_warrantee_alert' => ':count darab eszköznél a jótállás :threshold napon belül lejár.|:count darab eszköznél a jótállások :threshold napon belül lejárnak.',
    'license_expiring_alert' => ':count licensz lejár :thershold nap múlva.|:count licensz lejár :thershold nap múlva.',
    'to_reset' => 'A webes jelszó visszaállításához töltsd ki ezt az űrlapot:',
    'type' => 'típus',
    'upcoming-audits' => 'Várhatóan :count eszközt kell ellenőrízni a következő :threshold napon belül.|Várhatóan :count eszközt kell ellenőrízni a következő :threshold napon belül.',
    'user' => 'Felhasználó',
    'username' => 'Felhasználónév',
    'welcome' => 'Üdvözöljük: név',
    'welcome_to' => 'Üdvözöljük a weboldalon!',
    'your_credentials' => 'A Snipe-IT hitelesítő adatai',
    'Accessory_Checkin_Notification' => 'Tartozék kiadva',
    'Asset_Checkin_Notification' => 'Eszköz kiadva',
    'Asset_Checkout_Notification' => 'Eszköz kiadva',
    'License_Checkin_Notification' => 'Licensz kiadva',
    'Expected_Checkin_Report' => 'Várható eszköz kiadásának jelentése',
    'Expected_Checkin_Notification' => 'Emlékeztető: :name kiadásának idejéhez közelít',
    'Expected_Checkin_Date' => 'Az eszközt amelyet kiadtak neked, hamarosan visszavételre kerül a :date napon',
    'your_assets' => 'Eszközeidnek megtekíntése',
    'rights_reserved' => 'Minden jog fenntartva.',
];

==> snipe-it-7.0.11.zip: snipe-it-7.0.11/resources/lang/hu-HU/mail.php <==
<?php

return [

    'Accessory_Checkin_Notification' => 'Tartozék kiadva',
    'Accessory_Checkout_Notification' => 'Tartozék kiadva',
    'Asset_Checkin_Notification' => 'Eszköz kiadva',
    'Asset_Checkout_Notification' => 'Eszköz kiadva',
    'Confirm_Accessory_Checkin' => 'Tartozék visszavételének megerősítése',
    'Confirm_Asset_Checkin' => 'Eszköz visszavételének megerősítése',
    'Confirm_accessory_delivery' => 'Tartozék átvételének megerősítése',
    'Confirm_asset_delivery' => 'Eszköz átvételének megerősítése',
    'Confirm_consumable_delivery' => 'Fogyóeszköz átvételének megerősítése',
    'Confirm_license_delivery' => 'Licensz átvételének megerősítése',
    'Consumable_checkout_notification' => 'Consumable checked out',
    'Days' => 'Nap',
    'Expected_Checkin_Date' => 'Az eszközt amelyet kiadtak neked, hamarosan visszavételre kerül a :date napon',
    'Expected_Checkin_Notification' => 'Emlékeztető: :name kiadásának idejéhez közelít',
    'Expected_Checkin_Report' => 'Várható eszköz kiadásának jelentése',
    'Expiring_Assets_Report' => 'Eszközök lejárati jelentése.',
    'Expiring_Licenses_Report' => 'Az engedélyekről szóló jelentés lejárata.',
    'Item_Request_Canceled' => 'Elemkérelem törölve',
    'Item_Requested' => 'Kért elem',
    'License_Checkin_Notification' => 'Licensz kiadva',
    'License_Checkout_Notification' => 'License checked out',
    'Low_Inventory_Report' => 'Alacsony készletjelentés',
    'a_user_canceled' => 'A felhasználó törölte az elemkérést a webhelyen',
    'a_user_requested' => 'A felhasználó egy elemet kért a webhelyen',
    'acceptance_asset_accepted' => 'A felhasználó elfogadott egy tételt',
    'acceptance_asset_declined' => 'A felhasználó visszautasított egy tételt',
    'accessory_name' => 'Tartozéknév:',
    'additional_notes' => 'További megjegyzések:',
    'admin_has_created' => 'A rendszergazda létrehozott egy fiókot az alábbi weboldalon:',
    'asset' => 'Eszköz:',
    'asset_name' => 'Eszköz neve:',
    'asset_requested' => 'Asset requested',
    'asset_tag' => 'Eszköz azonosító',
    'assets_warrantee_alert' => ':count darab eszköznél a jótállás :threshold napon belül lejár.|:count darab eszköznél a jótállások :threshold napon belül lejárnak.',
    'assigned_to' => 'Hozzárendelve',
    'best_regards' => 'Üdvözlettel,',
    'canceled' => 'Megszakítva:',
    'checkin_date' => 'Visszavétel dátuma:',
    'checkout_date' => 'Kiadási dátum:',
    'checkedout_from' => 'Kiadva innen',
    'checkedin_from'  => 'Visszavéve innen',
    'checked_into' => 'Checked into',
    'click_on_the_link_accessory' => 'Az alján lévő linkre kattintva ellenőrizheti, hogy megkapta-e a tartozékot.',
    'click_on_the_link_asset' => 'Kérjük, kattintson az alul lévő linkre annak megerősítéséhez, hogy megkapták az eszközt.',
    'click_to_confirm' => 'Kérjük, kattintson az alábbi linkre a weboldal megerősítéséhez: web account:',
    'current_QTY' => 'Jelenlegi QTY',
    'days' => 'Nap',
    'expecting_checkin_date' => 'Várható visszaadás dátuma:',
    'expires' => 'Lejárat',
    'hello' => 'Helló',
    'hi' => 'Üdv',
    'i_have_read' => 'Elolvastam és elfogadom a felhasználási feltételeket, és megkaptuk ezt az elemet.',
    'inventory_report' => 'Készlet Jelentés',
    'item' => 'Tétel:',
    'item_checked_reminder' => 'Ez egy emlékeztető arról, hogy jelenleg :count számú jóváhagyásra váró eszköze van. Kérem, az alábbi linken döntsön ezek elfogadásáról, vagy elutasításáról.',
    'license_expiring_alert' => ':count licensz lejár :thershold nap múlva.|:count licensz lejár :thershold nap múlva.',
    'link_to_update_password' => 'Kérjük, kattintson a következő linkre a frissítéshez: webes jelszó:',
    'login' => 'Belépés:',
    'login_first_admin' => 'Jelentkezzen be az új Snipe-IT telepítésébe az alábbi hitelesítő adatok alapján:',
    'low_inventory_alert' => ':count darab tétel érhető el, ami kevesebb mint a minimum készlet vagy hamarosan kevesebb lesz.',
    'min_QTY' => 'Min QTY',
    'name' => 'Név',
    'new_item_checked' => 'Egy új elemet az Ön neve alatt ellenőriztek, a részletek lent találhatók.',
    'notes' => 'Jegyzetek',
    'password' => 'Jelszó:',
    'password_reset' => 'Jelszó visszaállítása',
    'read_the_terms' => 'Kérjük, olvassa el az alábbi használati feltételeket.',
    'read_the_terms_and_click' => 'Kérjük, a használati feltételek elolvasása után az alábbi linken erősítse meg annak elfogadását, és az eszköz átvételét.',
    'requested' => 'Kérve:',
    'reset_link' => 'Jelszó visszaállítása linkre',
    'reset_password' => 'Kattintson ide a jelszó visszaállításához:',
    'rights_reserved' => 'Minden jog fenntartva.',
    'serial' => 'Sorozatszám',
    'snipe_webhook_test' => 'Snipe-IT integráció teszt',
    'snipe_webhook_summary' => 'Snipe-IT integráció teszt eredmény',
    'supplier' => 'Támogató',
    'tag' => 'Címke',
    'test_email' => 'Tesztelje az e-mailt a Snipe-IT-től',
    'test_mail_text' => 'Ez a Snipe-IT Asset Management System tesztje. Ha ez megvan, a levél működik :)',
    'the_following_item' => 'A következő tételt ellenőrzik:',
    'to_reset' => 'A webes jelszó visszaállításához töltsd ki ezt az űrlapot:',
    'type' => 'típus',
    'upcoming-audits' => 'Várhatóan :count eszközt kell ellenőrízni a következő :threshold napon belül.|Várhatóan :count eszközt kell ellenőrízni a következő :threshold napon belül.',
    'user' => 'Felhasználó',
    'username' => 'Felhasználónév',
    'unaccepted_asset_reminder' => 'Elfogadatlan eszközei vannak.',
    'welcome' => 'Üdvözöljük: név',
    'welcome_to' => 'Üdvözöljük a weboldalon!',
    'your_assets' => 'Eszközeidnek megtekíntése',
    'your_credentials' => 'A Snipe-IT hitelesítő adatai',
    'mail_sent' => 'E-mail sikeresen elküldve!',
];
